BaseMethod class abstract

Constructors

BaseMethod({required HttpClient client})

Properties

client HttpClient
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getData<KT, VT>({dynamic data, bool slient = false, required String url, required dynamic encodeDataFunction(RespData resp), ClassBuffer<KT, VT>? buffer, String method = "POST"}) Future<RespData<VT?>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendReq<T>(String rawUrl, dynamic params, String method, bool slient) Future<RespData<T>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited