MultiPartParam class

Inheritance

Constructors

MultiPartParam()

Properties

contents Map<String, dynamic>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addValue(String name, dynamic value) → void
getReqInfo() Future<ReqInfo>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited