JsonReqInfo class

Inheritance

Constructors

JsonReqInfo({String contentType = "", Map<String, dynamic>? content, List<String>? urlParameters})

Properties

content → dynamic
no setterinherited
contentType String
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
urlParameters List<String>?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited