IPaginationController<T> class abstract

Contract used by http_method-generated *Fetch list methods. Keep this type stable; generated network.gen.g.dart references it via the app library that imports this file.

Implementers

Constructors

IPaginationController()

Properties

hashCode int
The hash code for this object.
no setterinherited
pageNum int
no setter
pageSize int
no setter
param → T
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setTotalCount(int total) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited