PaginationController<T> class

Inheritance
Implemented types

Constructors

PaginationController({int initialPageNo = 0, int initialPageSize = 10, required T initialParam})

Properties

canGoNext bool
no setter
canGoPrevious bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
pageCount int
no setter
pageNum int
no setteroverride
pageSize int
no setteroverride
param → T
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
no setter
totalPages int
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
goToPage(int page) → void
nextPage() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
previousPage() → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset() → void
setPageNo(int pageNo) → void
setPageSize(int pageSize) → void
setTotalCount(int total) → void
override
toString() String
A string representation of this object.
inherited
triggerRefresh() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited