WindowManagerController class
数据WindowManager对象;
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeTop(
) → void -
override
-
removeWidget(
Widget widget, {int level = 0, dynamic result}) → void -
override
-
showAlert(
AlertWidget widget, {int defaultValue = 0, bool barrierDismissible = true, Color? barrierColor = Colors.black54}) → Future< int?> -
override
-
showBy(
Widget widget, ContextGetter contextGetter) → void -
showBy基本都show菜单等,所以暂时不提供返回值
override
-
showDlg<
T> (Widget widget, {bool barrierDismissible = true, Color? barrierColor = Colors.black54, dynamic result}) → Future< T?> -
var app1 = await widget.manager.showDlg;则系统认为T是Object?
var app1; app1 = await widget.manager.showDlg;则系统认为T是dynamic;
App app1 = await widget.manager.showDlg;则系统认为T是Future
override
-
showWidget<
T> (Widget widget, {int level = 0, bool dragAble = false, double? top, double? left, double? right, double? bottom, bool indexAble = false, bool edgeAble = false}) → Future< T?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
totast(
String content, [int timeoutSeconds = 3]) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited